"use client";

import { Checkbox } from "@/components/ui/checkbox";
import {
  Command,
  CommandGroup,
  CommandItem,
  CommandList,
  CommandSeparator,
} from "@/components/ui/command";
import { cn } from "@/lib/utils";
import {
  DropdownMenu,
  DropdownMenuTrigger,
  DropdownMenuContent,
  DropdownMenuLabel,
  DropdownMenuSeparator,
  DropdownMenuItem,
} from "@/components/ui/dropdown-menu";
import {
  Check,
  Edit,
  MoreHorizontal,
  MoreVertical,
  Plus,
  Trash2,
} from "lucide-react";
import React, { useState } from "react";
import { Button } from "@/components/ui/button";

const TagList2Options = () => {
  return (
    <DropdownMenu>
      <DropdownMenuTrigger>
        <Button variant="ghost" className="w-fit h-fit p-0">
          <MoreHorizontal className="w-4 h-4" strokeWidth={1.5} />
        </Button>
      </DropdownMenuTrigger>
      <DropdownMenuContent>
        <DropdownMenuItem className="cursor-pointer">
          <Edit className="w-4 h-4 mr-2" />
          <span>编辑</span>
        </DropdownMenuItem>
        <DropdownMenuItem className="cursor-pointer text-red-600 focus:text-red-600">
          <Trash2 className="w-4 h-4 mr-2" />
          <span>删除</span>
        </DropdownMenuItem>
      </DropdownMenuContent>
    </DropdownMenu>
  );
};

interface ITagListProps extends React.HTMLAttributes<HTMLDivElement> {
  list: TagItem[];
}

export default function TagList2({ list, className }: ITagListProps) {
  const [selectedTags, setSelectedTags] = useState<string[]>([]);
  const handleSelect = (id: string) => {
    if (selectedTags.includes(id)) {
      setSelectedTags(selectedTags.filter((it) => it !== id));
    } else {
      setSelectedTags([...selectedTags, id]);
    }
  };
  return (
    <Command className={cn("rounded-lg border shadow-md h-fit p-2", className)}>
      <CommandList>
        <CommandGroup>
          <CommandItem className="flex justify-between items-center cursor-pointer">
            <span>显示全部</span>
            {!(selectedTags.length > 0) && (
              <Check className="ml-2 h-4 w-4 text-primary" />
            )}
          </CommandItem>
        </CommandGroup>
        <CommandSeparator />
        <CommandGroup>
          {list.map((tag) => (
            <CommandItem
              value={tag.id + ""}
              key={tag.id}
              className="flex justify-between items-center cursor-pointer"
            >
              <div className="flex justify-start items-center gap-2">
                <Checkbox
                  checked={selectedTags.includes(tag.id + "")}
                  onClick={() => handleSelect(tag.id + "")}
                />
                <div className={cn("h-2 w-2 rounded-[2px]", tag.color)} />
                <span>{tag.name}</span>
              </div>
              <TagList2Options />
            </CommandItem>
          ))}
        </CommandGroup>
        <CommandSeparator />
        <CommandGroup>
          <CommandItem className="cursor-pointer">
            <Plus className="w-4 h-4 mr-2" />
            <span>新建标签</span>
          </CommandItem>
        </CommandGroup>
      </CommandList>
    </Command>
  );
}
